@@ -29,6 +29,7 @@
 #include "auth.h"
 #include "smbprofile.h"
 #include "libsmb/libsmb.h"
+#include "lib/util_ea.h"
 
 extern const struct generic_mapping file_generic_mapping;
 
@@ -718,6 +719,7 @@ void reply_ntcreate_and_X(struct smb_request *req)
 		uint32 perms = 0;
 		p += 25;
 		if (fsp->is_directory ||
+		    fsp->can_write ||
 		    can_write_to_file(conn, smb_fname)) {
 			perms = FILE_GENERIC_ALL;
 		} else {
@@ -963,49 +965,6 @@ NTSTATUS set_sd_blob(files_struct *fsp, uint8_t *data, uint32_t sd_len,
 	return set_sd(fsp, psd, security_info_sent);
 }
 
-/****************************************************************************
- Read a list of EA names and data from an incoming data buffer. Create an ea_list with them.
-****************************************************************************/
-
-struct ea_list *read_nttrans_ea_list(TALLOC_CTX *ctx, const char *pdata, size_t data_size)
-{
-	struct ea_list *ea_list_head = NULL;
-	size_t offset = 0;
-
-	if (data_size < 4) {
-		return NULL;
-	}
-
-	while (offset + 4 <= data_size) {
-		size_t next_offset = IVAL(pdata,offset);
-		struct ea_list *eal = read_ea_list_entry(ctx, pdata + offset + 4, data_size - offset - 4, NULL);
-
-		if (!eal) {
-			return NULL;
-		}
-
-		DLIST_ADD_END(ea_list_head, eal, struct ea_list *);
-		if (next_offset == 0) {
-			break;
-		}
-
-		/* Integer wrap protection for the increment. */
-		if (offset + next_offset < offset) {
-			break;
-		}
-
-		offset += next_offset;
-
-		/* Integer wrap protection for while loop. */
-		if (offset + 4 < offset) {
-			break;
-		}
-
-	}
-
-	return ea_list_head;
-}
-
 /****************************************************************************
  Reply to a NT_TRANSACT_CREATE call (needs to process SD's).
 ****************************************************************************/
@@ -1372,6 +1331,7 @@ static void call_nt_transact_create(connection_struct *conn,
 		uint32 perms = 0;
 		p += 25;
 		if (fsp->is_directory ||
+		    fsp->can_write ||
 		    can_write_to_file(conn, smb_fname)) {
 			perms = FILE_GENERIC_ALL;
 		} else {
@@ -2086,8 +2046,7 @@ static void call_nt_transact_query_security_desc(connection_struct *conn,
 	status = smbd_do_query_security_desc(conn,
 					talloc_tos(),
 					fsp,
-					security_info_wanted &
-					SMB_SUPPORTED_SECINFO_FLAGS,
+					security_info_wanted,
 					max_data_count,
 					&marshalled_sd,
 					&sd_size);
@@ -2180,8 +2139,8 @@ static void call_nt_transact_set_security_desc(connection_struct *conn,
 		return;
 	}
 
-	status = set_sd_blob(fsp, (uint8 *)data, data_count,
-			     security_info_sent & SMB_SUPPORTED_SECINFO_FLAGS);
+	status = set_sd_blob(fsp, (uint8 *)data, data_count, security_info_sent);
+
 	if (!NT_STATUS_IS_OK(status)) {
 		reply_nterror(req, status);
 		return;
