@@ -24,6 +24,7 @@
 #include "rpc_server/dcerpc_server.h"
 #include "librpc/gen_ndr/ndr_srvsvc.h"
 #include "rpc_server/common/common.h"
+#include "rpc_server/common/share.h"
 #include "auth/auth.h"
 #include "libcli/security/security.h"
 #include "system/time.h"
@@ -33,7 +34,7 @@
 #define SRVSVC_CHECK_ADMIN_ACCESS do { \
 	struct security_token *t = dce_call->conn->auth_state.session_info->security_token; \
 	if (!security_token_has_builtin_administrators(t) && \
-	    !security_token_has_sid_string(t, SID_BUILTIN_SERVER_OPERATORS)) { \
+	    !security_token_has_sid(t, &global_sid_Builtin_Server_Operators)) { \
 	    	return WERR_ACCESS_DENIED; \
 	} \
 } while (0)
@@ -68,8 +69,6 @@ static WERROR dcesrv_srvsvc_NetCharDevEnum(struct dcesrv_call_state *dce_call, T
 	default:
 		return WERR_UNKNOWN_LEVEL;
 	}
-
-	return WERR_OK;
 }
 
 
@@ -93,8 +92,6 @@ static WERROR dcesrv_srvsvc_NetCharDevGetInfo(struct dcesrv_call_state *dce_call
 	default:
 		return WERR_UNKNOWN_LEVEL;
 	}
-
-	return WERR_UNKNOWN_LEVEL;
 }
 
 
@@ -140,8 +137,6 @@ static WERROR dcesrv_srvsvc_NetCharDevQEnum(struct dcesrv_call_state *dce_call,
 	default:
 		return WERR_UNKNOWN_LEVEL;
 	}
-
-	return WERR_UNKNOWN_LEVEL;
 }
 
 
@@ -165,8 +160,6 @@ static WERROR dcesrv_srvsvc_NetCharDevQGetInfo(struct dcesrv_call_state *dce_cal
 	default:
 		return WERR_UNKNOWN_LEVEL;
 	}
-
-	return WERR_UNKNOWN_LEVEL;
 }
 
 
@@ -194,8 +187,6 @@ static WERROR dcesrv_srvsvc_NetCharDevQSetInfo(struct dcesrv_call_state *dce_cal
 	default:
 		return WERR_UNKNOWN_LEVEL;
 	}
-
-	return WERR_UNKNOWN_LEVEL;
 }
 
 
@@ -251,8 +242,6 @@ static WERROR dcesrv_srvsvc_NetConnEnum(struct dcesrv_call_state *dce_call, TALL
 	default:
 		return WERR_UNKNOWN_LEVEL;
 	}
-
-	return WERR_UNKNOWN_LEVEL;
 }
 
 
@@ -288,8 +277,6 @@ static WERROR dcesrv_srvsvc_NetFileEnum(struct dcesrv_call_state *dce_call, TALL
 	default:
 		return WERR_UNKNOWN_LEVEL;
 	}
-
-	return WERR_UNKNOWN_LEVEL;
 }
 
 
@@ -313,8 +300,6 @@ static WERROR dcesrv_srvsvc_NetFileGetInfo(struct dcesrv_call_state *dce_call, T
 	default:
 		return WERR_UNKNOWN_LEVEL;
 	}
-
-	return WERR_UNKNOWN_LEVEL;
 }
 
 
@@ -390,8 +375,6 @@ static WERROR dcesrv_srvsvc_NetSessEnum(struct dcesrv_call_state *dce_call, TALL
 	default:
 		return WERR_UNKNOWN_LEVEL;
 	}
-
-	return WERR_UNKNOWN_LEVEL;
 }
 
 
@@ -431,10 +414,10 @@ static WERROR dcesrv_srvsvc_NetShareAdd(struct dcesrv_call_state *dce_call, TALL
 		NTSTATUS nterr;
 		struct share_info *info;
 		struct share_context *sctx;
-		int count = 8;
-		int i;
+		unsigned int count = 8;
+		unsigned int i;
 
-		nterr = share_get_context_by_name(mem_ctx, lp_share_backend(dce_call->conn->dce_ctx->lp_ctx), dce_call->event_ctx, dce_call->conn->dce_ctx->lp_ctx, &sctx);
+		nterr = share_get_context_by_name(mem_ctx, lpcfg_share_backend(dce_call->conn->dce_ctx->lp_ctx), dce_call->event_ctx, dce_call->conn->dce_ctx->lp_ctx, &sctx);
 		if (!NT_STATUS_IS_OK(nterr)) {
 			return ntstatus_to_werror(nterr);
 		}
@@ -448,13 +431,13 @@ static WERROR dcesrv_srvsvc_NetShareAdd(struct dcesrv_call_state *dce_call, TALL
 		info[i].name = SHARE_TYPE;
 		info[i].type = SHARE_INFO_STRING;
 		switch (r->in.info->info2->type) {
-		case 0x00:
+		case STYPE_DISKTREE:
 			info[i].value = talloc_strdup(info, "DISK");
 			break;
-		case 0x01:
+		case STYPE_PRINTQ:
 			info[i].value = talloc_strdup(info, "PRINTER");
 			break;
-		case 0x03:
+		case STYPE_IPC:
 			info[i].value = talloc_strdup(info, "IPC");
 			break;
 		default:
@@ -529,10 +512,10 @@ static WERROR dcesrv_srvsvc_NetShareAdd(struct dcesrv_call_state *dce_call, TALL
 		NTSTATUS nterr;
 		struct share_info *info;
 		struct share_context *sctx;
-		int count = 10;
-		int i;
+		unsigned int count = 10;
+		unsigned int i;
 
-		nterr = share_get_context_by_name(mem_ctx, lp_share_backend(dce_call->conn->dce_ctx->lp_ctx), dce_call->event_ctx, dce_call->conn->dce_ctx->lp_ctx, &sctx);
+		nterr = share_get_context_by_name(mem_ctx, lpcfg_share_backend(dce_call->conn->dce_ctx->lp_ctx), dce_call->event_ctx, dce_call->conn->dce_ctx->lp_ctx, &sctx);
 		if (!NT_STATUS_IS_OK(nterr)) {
 			return ntstatus_to_werror(nterr);
 		}
@@ -618,8 +601,6 @@ static WERROR dcesrv_srvsvc_NetShareAdd(struct dcesrv_call_state *dce_call, TALL
 	default:
 		return WERR_UNKNOWN_LEVEL;
 	}
-
-	return WERR_UNKNOWN_LEVEL;
 }
 
 static WERROR dcesrv_srvsvc_fiel_ShareInfo(struct dcesrv_call_state *dce_call, TALLOC_CTX *mem_ctx,
@@ -699,8 +680,6 @@ static WERROR dcesrv_srvsvc_fiel_ShareInfo(struct dcesrv_call_state *dce_call, T
 	default:
 		return WERR_UNKNOWN_LEVEL;
 	}
-
-	return WERR_UNKNOWN_LEVEL;
 }
 
 /* 
@@ -720,7 +699,7 @@ static WERROR dcesrv_srvsvc_NetShareEnumAll(struct dcesrv_call_state *dce_call,
 	/* TODO: - paging of results 
 	 */
 
-	nterr = share_get_context_by_name(mem_ctx, lp_share_backend(dce_call->conn->dce_ctx->lp_ctx), dce_call->event_ctx, dce_call->conn->dce_ctx->lp_ctx, &sctx);
+	nterr = share_get_context_by_name(mem_ctx, lpcfg_share_backend(dce_call->conn->dce_ctx->lp_ctx), dce_call->event_ctx, dce_call->conn->dce_ctx->lp_ctx, &sctx);
 	if (!NT_STATUS_IS_OK(nterr)) {
 		return ntstatus_to_werror(nterr);
 	}
@@ -733,7 +712,7 @@ static WERROR dcesrv_srvsvc_NetShareEnumAll(struct dcesrv_call_state *dce_call,
 	switch (r->in.info_ctr->level) {
 	case 0:
 	{
-		int i;
+		unsigned int i;
 		struct srvsvc_NetShareCtr0 *ctr0;
 
 		ctr0 = talloc(mem_ctx, struct srvsvc_NetShareCtr0);
@@ -774,7 +753,7 @@ static WERROR dcesrv_srvsvc_NetShareEnumAll(struct dcesrv_call_state *dce_call,
 	}
 	case 1:
 	{
-		int i;
+		unsigned int i;
 		struct srvsvc_NetShareCtr1 *ctr1;
 
 		ctr1 = talloc(mem_ctx, struct srvsvc_NetShareCtr1);
@@ -816,7 +795,7 @@ static WERROR dcesrv_srvsvc_NetShareEnumAll(struct dcesrv_call_state *dce_call,
 	}
 	case 2:
 	{
-		int i;
+		unsigned int i;
 		struct srvsvc_NetShareCtr2 *ctr2;
 
 		SRVSVC_CHECK_ADMIN_ACCESS;
@@ -860,7 +839,7 @@ static WERROR dcesrv_srvsvc_NetShareEnumAll(struct dcesrv_call_state *dce_call,
 	}
 	case 501:
 	{
-		int i;
+		unsigned int i;
 		struct srvsvc_NetShareCtr501 *ctr501;
 
 		SRVSVC_CHECK_ADMIN_ACCESS;
@@ -904,7 +883,7 @@ static WERROR dcesrv_srvsvc_NetShareEnumAll(struct dcesrv_call_state *dce_call,
 	}
 	case 502:
 	{
-		int i;
+		unsigned int i;
 		struct srvsvc_NetShareCtr502 *ctr502;
 
 		SRVSVC_CHECK_ADMIN_ACCESS;
@@ -949,8 +928,6 @@ static WERROR dcesrv_srvsvc_NetShareEnumAll(struct dcesrv_call_state *dce_call,
 	default:
 		return WERR_UNKNOWN_LEVEL;
 	}
-
-	return WERR_UNKNOWN_LEVEL;
 }
 
 
@@ -973,7 +950,7 @@ static WERROR dcesrv_srvsvc_NetShareGetInfo(struct dcesrv_call_state *dce_call,
 		return WERR_INVALID_PARAM;
 	}
 
-	nterr = share_get_context_by_name(mem_ctx, lp_share_backend(dce_call->conn->dce_ctx->lp_ctx), dce_call->event_ctx, dce_call->conn->dce_ctx->lp_ctx, &sctx);
+	nterr = share_get_context_by_name(mem_ctx, lpcfg_share_backend(dce_call->conn->dce_ctx->lp_ctx), dce_call->event_ctx, dce_call->conn->dce_ctx->lp_ctx, &sctx);
 	if (!NT_STATUS_IS_OK(nterr)) {
 		return ntstatus_to_werror(nterr);
 	}
@@ -1087,8 +1064,6 @@ static WERROR dcesrv_srvsvc_NetShareGetInfo(struct dcesrv_call_state *dce_call,
 	default:
 		return WERR_UNKNOWN_LEVEL;
 	}
-
-	return WERR_UNKNOWN_LEVEL;
 }
 
 static WERROR dcesrv_srvsvc_fill_share_info(struct share_info *info, int *count,
@@ -1102,7 +1077,7 @@ static WERROR dcesrv_srvsvc_fill_share_info(struct share_info *info, int *count,
 					uint32_t csc_policy,
 					struct security_descriptor *sd)
 {
-	int i = 0;
+	unsigned int i = 0;
 
 	if (level == 501) {
 		info[i].name = SHARE_CSC_POLICY;
@@ -1221,13 +1196,11 @@ static WERROR dcesrv_srvsvc_NetShareSetInfo(struct dcesrv_call_state *dce_call,
 	info = talloc_array(mem_ctx, struct share_info, 10);
 	W_ERROR_HAVE_NO_MEMORY(info);
 
-	ZERO_STRUCT(r->out);
-
 	if (strcmp("", r->in.share_name) == 0) {
 		return WERR_INVALID_PARAM;
 	}
 
-	nterr = share_get_context_by_name(mem_ctx, lp_share_backend(dce_call->conn->dce_ctx->lp_ctx), dce_call->event_ctx, dce_call->conn->dce_ctx->lp_ctx, &sctx);
+	nterr = share_get_context_by_name(mem_ctx, lpcfg_share_backend(dce_call->conn->dce_ctx->lp_ctx), dce_call->event_ctx, dce_call->conn->dce_ctx->lp_ctx, &sctx);
 	if (!NT_STATUS_IS_OK(nterr)) {
 		return ntstatus_to_werror(nterr);
 	}
@@ -1383,7 +1356,8 @@ static WERROR dcesrv_srvsvc_NetShareCheck(struct dcesrv_call_state *dce_call, TA
 	struct share_config *scfg = NULL;
 	char *device;
 	const char **names;
-	int count, i;
+	int count;
+	int i;
 
 	*r->out.type = 0;
 
@@ -1404,7 +1378,7 @@ static WERROR dcesrv_srvsvc_NetShareCheck(struct dcesrv_call_state *dce_call, TA
 	}
 	all_string_sub(device, "\\", "/", 0);
 
-	nterr = share_get_context_by_name(mem_ctx, lp_share_backend(dce_call->conn->dce_ctx->lp_ctx), dce_call->event_ctx, dce_call->conn->dce_ctx->lp_ctx, &sctx);
+	nterr = share_get_context_by_name(mem_ctx, lpcfg_share_backend(dce_call->conn->dce_ctx->lp_ctx), dce_call->event_ctx, dce_call->conn->dce_ctx->lp_ctx, &sctx);
 	if (!NT_STATUS_IS_OK(nterr)) {
 		return ntstatus_to_werror(nterr);
 	}
@@ -1457,7 +1431,7 @@ static WERROR dcesrv_srvsvc_NetSrvGetInfo(struct dcesrv_call_state *dce_call, TA
 		       struct srvsvc_NetSrvGetInfo *r)
 {
 	struct dcesrv_context *dce_ctx = dce_call->conn->dce_ctx;
-	struct dcerpc_server_info *server_info = lp_dcerpc_server_info(mem_ctx, dce_ctx->lp_ctx);
+	struct dcerpc_server_info *server_info = lpcfg_dcerpc_server_info(mem_ctx, dce_ctx->lp_ctx);
 
 	ZERO_STRUCTP(r->out.info);
 
@@ -1490,7 +1464,7 @@ static WERROR dcesrv_srvsvc_NetSrvGetInfo(struct dcesrv_call_state *dce_call, TA
 		info101->version_major	= server_info->version_major;
 		info101->version_minor	= server_info->version_minor;
 		info101->server_type	= dcesrv_common_get_server_type(mem_ctx, dce_call->event_ctx, dce_ctx);
-		info101->comment	= talloc_strdup(mem_ctx, lp_serverstring(dce_ctx->lp_ctx));
+		info101->comment	= talloc_strdup(mem_ctx, lpcfg_serverstring(dce_ctx->lp_ctx));
 		W_ERROR_HAVE_NO_MEMORY(info101->comment);
 
 		r->out.info->info101 = info101;
@@ -1510,7 +1484,7 @@ static WERROR dcesrv_srvsvc_NetSrvGetInfo(struct dcesrv_call_state *dce_call, TA
 		info102->version_major	= server_info->version_major;
 		info102->version_minor	= server_info->version_minor;
 		info102->server_type	= dcesrv_common_get_server_type(mem_ctx, dce_call->event_ctx, dce_ctx);
-		info102->comment	= talloc_strdup(mem_ctx, lp_serverstring(dce_ctx->lp_ctx));
+		info102->comment	= talloc_strdup(mem_ctx, lpcfg_serverstring(dce_ctx->lp_ctx));
 		W_ERROR_HAVE_NO_MEMORY(info102->comment);
 
 		info102->users		= dcesrv_common_get_users(mem_ctx, dce_ctx);
@@ -1528,8 +1502,6 @@ static WERROR dcesrv_srvsvc_NetSrvGetInfo(struct dcesrv_call_state *dce_call, TA
 	default:
 		return WERR_UNKNOWN_LEVEL;
 	}
-
-	return WERR_UNKNOWN_LEVEL;
 }
 
 
@@ -1576,8 +1548,6 @@ static WERROR dcesrv_srvsvc_NetDiskEnum(struct dcesrv_call_state *dce_call, TALL
 	default:
 		return WERR_UNKNOWN_LEVEL;
 	}
-
-	return WERR_UNKNOWN_LEVEL;
 }
 
 
@@ -1657,8 +1627,6 @@ static WERROR dcesrv_srvsvc_NetTransportEnum(struct dcesrv_call_state *dce_call,
 	default:
 		return WERR_UNKNOWN_LEVEL;
 	}
-
-	return WERR_UNKNOWN_LEVEL;
 }
 
 /* 
@@ -1787,8 +1755,6 @@ static WERROR dcesrv_srvsvc_NetNameValidate(struct dcesrv_call_state *dce_call,
 	default:
 		return WERR_INVALID_PARAM;
 	}
-
-	return WERR_INVALID_PARAM;
 }
 
 
@@ -1820,7 +1786,7 @@ static WERROR dcesrv_srvsvc_NetShareEnum(struct dcesrv_call_state *dce_call, TAL
 	/* TODO: - paging of results 
 	 */
 
-	nterr = share_get_context_by_name(mem_ctx, lp_share_backend(dce_call->conn->dce_ctx->lp_ctx), dce_call->event_ctx, dce_call->conn->dce_ctx->lp_ctx, &sctx);
+	nterr = share_get_context_by_name(mem_ctx, lpcfg_share_backend(dce_call->conn->dce_ctx->lp_ctx), dce_call->event_ctx, dce_call->conn->dce_ctx->lp_ctx, &sctx);
 	if (!NT_STATUS_IS_OK(nterr)) {
 		return ntstatus_to_werror(nterr);
 	}
@@ -1833,8 +1799,8 @@ static WERROR dcesrv_srvsvc_NetShareEnum(struct dcesrv_call_state *dce_call, TAL
 	switch (r->in.info_ctr->level) {
 	case 0:
 	{
-		int i, y = 0;
-		int count;
+		unsigned int i, y = 0;
+		unsigned int count;
 		struct srvsvc_NetShareCtr0 *ctr0;
 
 		ctr0 = talloc(mem_ctx, struct srvsvc_NetShareCtr0);
@@ -1885,8 +1851,8 @@ static WERROR dcesrv_srvsvc_NetShareEnum(struct dcesrv_call_state *dce_call, TAL
 	}
 	case 1:
 	{
-		int i, y = 0;
-		int count;
+		unsigned int i, y = 0;
+		unsigned int count;
 		struct srvsvc_NetShareCtr1 *ctr1;
 
 		ctr1 = talloc(mem_ctx, struct srvsvc_NetShareCtr1);
@@ -1937,8 +1903,8 @@ static WERROR dcesrv_srvsvc_NetShareEnum(struct dcesrv_call_state *dce_call, TAL
 	}
 	case 2:
 	{
-		int i, y = 0;
-		int count;
+		unsigned int i, y = 0;
+		unsigned int count;
 		struct srvsvc_NetShareCtr2 *ctr2;
 
 		SRVSVC_CHECK_ADMIN_ACCESS;
@@ -1991,8 +1957,8 @@ static WERROR dcesrv_srvsvc_NetShareEnum(struct dcesrv_call_state *dce_call, TAL
 	}
 	case 502:
 	{
-		int i, y = 0;
-		int count;
+		unsigned int i, y = 0;
+		unsigned int count;
 		struct srvsvc_NetShareCtr502 *ctr502;
 
 		SRVSVC_CHECK_ADMIN_ACCESS;
@@ -2046,8 +2012,6 @@ static WERROR dcesrv_srvsvc_NetShareEnum(struct dcesrv_call_state *dce_call, TAL
 	default:
 		return WERR_UNKNOWN_LEVEL;
 	}
-
-	return WERR_UNKNOWN_LEVEL;
 }
 
 
@@ -2287,7 +2251,7 @@ static WERROR dcesrv_srvsvc_NetShareDel(struct dcesrv_call_state *dce_call, TALL
 	NTSTATUS nterr;
 	struct share_context *sctx;
 		
-	nterr = share_get_context_by_name(mem_ctx, lp_share_backend(dce_call->conn->dce_ctx->lp_ctx), dce_call->event_ctx, dce_call->conn->dce_ctx->lp_ctx, &sctx);
+	nterr = share_get_context_by_name(mem_ctx, lpcfg_share_backend(dce_call->conn->dce_ctx->lp_ctx), dce_call->event_ctx, dce_call->conn->dce_ctx->lp_ctx, &sctx);
 	if (!NT_STATUS_IS_OK(nterr)) {
 		return ntstatus_to_werror(nterr);
 	}
